@@ -5,7 +5,7 @@
 # Author: Andrew Turpin    (aturpin@unimelb.edu.au)
 # Date: June 2012
 #
-# Copyright 2012 Andrew Turpin and Jonathan Denniss
+# Copyright 2012 Andrew Turpin
 # This program is part of the OPI (http://perimetry.org/OPI).
 # OPI is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,34 +22,61 @@
 #
 
 simG.opiClose         <- function() { return(NULL) }
-simG.opiSetBackground <- function() { return(NULL) }
 simG.opiQueryDevice   <- function() { return (list(type="SimGaussian")) }
 
+.SimGEnv <- new.env(size=1)
+
 ################################################################################
 # Input
 #   sd standard deviation for the Gaussian
+#   display Dimensions of plot area to display stim. No display if NULL
 #
 # Return NULL if succesful, string error message otherwise  
 ################################################################################
-simG.opiInitialize <- function(sd) {
+simG.opiInitialize <- function(sd, display=NULL) {
     if (!is.numeric(sd) || (sd < 0)) {
         msg <- paste("Invalid standard deviation in opiInitialize for SimGaussian:",sd)
         warning(msg)
         return(msg)
     }
 
-    assign("simG.global.sd", sd, envir = .GlobalEnv)
+    .SimGEnv$sd <- sd
+
+    if (simDisplay.setupDisplay(display))
+        warning("opiInitialize (SimGaussian): perhaps display parameter does not contain 4 numbers?")
+
     return(NULL)
 }
 
 ################################################################################
-simG.global.sd <- NA
-
+# Set background of plot area to col, color of gird lines to gridCol
+################################################################################
+simG.opiSetBackground <- function(col, gridCol) { 
+    simDisplay.setBackground(col, gridCol)
+    return(NULL) 
+}
+################################################################################
 simG.opiPresent <- function(stim, nextStim=NULL, fpr=0.03, fnr=0.01, tt=30) { UseMethod("simG.opiPresent") }
 setGeneric("simG.opiPresent")
 
 simG.opiPresent.opiStaticStimulus <- function(stim, nextStim=NULL, fpr=0.03, fnr=0.01, tt=30) {
-    prSeeing <- fpr + (1-fpr-fnr)*(1-pnorm(cdTodb(stim$level), mean=tt, sd=.GlobalEnv$simG.global.sd))
+    if (!exists("sd", envir=.SimGEnv)) {
+        return ( list(
+            err = "opiInitialize(sd) was not called before opiPresent()",
+            seen= NA,
+            time= NA 
+        ))
+    }
+
+    if (is.null(stim))
+        stop("stim is NULL in call to opiPresent (using simGaussian, opiStaticStimulus)")
+
+    if (as.numeric(.SimGEnv$sd) <= 0)
+        warning("sd is <= 0 in SimGaussian call to opiPresent")
+
+    prSeeing <- fpr + (1-fpr-fnr)*(1-pnorm(cdTodb(stim$level), mean=tt, sd=as.numeric(.SimGEnv$sd)))
+
+    simDisplay.present(stim$x, stim$y, stim$color, stim$duration, stim$responseWindow)
 
     return ( list(
         err = NULL,
